# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.12
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.table_connections403_response import TableConnections403Response

class TestTableConnections403Response(unittest.TestCase):
    """TableConnections403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TableConnections403Response:
        """Test TableConnections403Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TableConnections403Response`
        """
        model = TableConnections403Response()
        if include_optional:
            return TableConnections403Response(
                detail = 'You do not have permission to access this application's data.'
            )
        else:
            return TableConnections403Response(
        )
        """

    def testTableConnections403Response(self):
        """Test TableConnections403Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.12
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ApiKeyDistributionEnum(str, Enum):
    """
    * `header` - Header * `query` - Query Parameter * `body` - Body Parameter
    """

    """
    allowed enum values
    """
    HEADER = 'header'
    QUERY = 'query'
    BODY = 'body'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ApiKeyDistributionEnum from a JSON string"""
        return cls(json.loads(json_str))


